#
# spec file for package python-interrogate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-interrogate
Version:        1.7.0
Release:        1.5
Summary:        Interrogate a codebase for docstring coverage
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/econchick/interrogate
Source:         https://files.pythonhosted.org/packages/source/i/interrogate/interrogate-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs
Requires:       python-click
Requires:       python-colorama
Requires:       python-py
Requires:       python-tabulate
%if 0%{python_version_nodots} < 311
Requires:       python-tomli
%endif
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module attrs}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module colorama}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module py}
BuildRequires:  %{python_module tabulate}
BuildRequires:  %{python_module tomli if %python-version < 3.11}
# /SECTION
%python_subpackages

%description
Interrogate a codebase for docstring coverage.

%prep
%setup -q -n interrogate-%{version}
rm tox.ini

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/interrogate
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative interrogate

%postun
%python_uninstall_alternative interrogate

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/interrogate
%{python_sitelib}/*

%changelog
* Sat Apr 20 2024 Dirk Müller <dmueller@suse.com>
- update to 1.7.0:
  * tomli dependency for Python versions < 3.11, making use of
    tomllib in the standard library with 3.11+ (#150).
  * Support for pyi file extensions (and leave room for other
    file extensions to be added, like maybe ipynb).
  * Support for Google-style docstrings for class __init__
    methods with new --style [sphinx|google] flag (#128).
  * Include support for deleters when ignoring property
    decorators (#126
    <https://github.com/econchick/interrogate/issues/126>_).
  * Support floats for --fail-under values (#114).
  * toml dependency for all Python versions (#150).
  * Add --ignore-overloaded-functions flag to ignore overload
    decorators (#97) – thank you ErwinJunge (via #167) and
    zackyancey.
  * Support for Python 3.11 & 3.12.
  * Support for Python 3.6 & 3.7.
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.5.0 (2021-09-10)
  Added
  * Set minimum click version (thank you bildzeitung! #81, #82).
  * Add --omit-covered-files flag to skip reporting fully-covered files (#85).
  * Add support for different badge styles via new --badge-style flag (#86).
  * Add 3.10 support!
  Fixed
  * Clarify verbose configuration (#83).
- Update to 1.4.0 (2021-05-14)
  Added
  * Support for generating the status badge as a PNG file with a new --badge-format flag (#70).
  * Add new option -C / --ignore-nested-classes to ignore – you guessed it – nested classes (#65).
  * Add new option -S / --ignore-setters to ignore property setter decorators (#68).
- Update to 1.3.2 (2020-11-03)
  * Added
  * Add wicked cute Sloth logo to status badge (#48).
  * Testing/support for Python 3.9 – thank you s-weigand!
  Fixed
  * Excluding paths are no longer OS-dependent (#51) – thank you oriash93!
  * Include Python trove classifiers in packaging (#61) – thank you mmtj!
  Removed
  * Support for Python 3.5 – thank you s-weigand!
- Update to 1.3.1 (2020-09-03)
  Fixed
  * Only generate a status badge if results have changed from an existing badge (#40).
- Update to 1.3.0 (2020-08-23)
  Added
  * Read configuration from pyproject.toml by default (#36).
  * Add -P / --ignore-property-decorators flag to ignore methods with property getter/setter decorators (#37).
  * Add support for read configuration from setup.cfg (#35).
  Fixed
  * -e / --exclude doesn’t error if a non-existent file/directory is passed (#38 - thank you MarcoGorelli!).
* Tue Aug 18 2020 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.2.0
